import { Editor } from 'codemirror';
import type { EditorConfiguration } from 'codemirror';
import { FormatOptions } from 'sql-formatter';
import { default as React_2 } from 'react';

export declare type IEditor = Editor & {
    format(options: Partial<FormatOptions>): void;
};

export declare type IFormatOptions = FormatOptions;

export declare const ReactCodemirror: React_2.ForwardRefExoticComponent<ReactCodemirrorProps & React_2.RefAttributes<Editor>>;

declare type ReactCodemirrorProps = {
    /**
     * @description 编辑器展示的内容文本
     */
    value?: string;
    /**
     * @description codemirror的配置，
     * @link {https://codemirror.net/doc/manual.html#config}
     */
    options?: EditorConfiguration & {
        formatOptions?: IFormatOptions;
    };
    /**
     * @description editor发生后出发的事件，用来获取更改后，editor的内容
     */
    onChange?: (value: string) => void;
    /**
     * @description 拓展自动补全功能，提供外部方法来补从不全的待选项
     */
    extraCompletions?: string[] | ((word: string) => string[] | Promise<string[]>);
};

export { }
